/*
PiAnoS (Picture Annotation System), A fingerprint examiner training tool
Copyright (C) 2011-2012 University of Lausanne, Switzerland
https://ips-labs.unil.ch/pianos

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see http://www.gnu.org/licenses/.
*/

Pianos4Backend.UserHome = function(selector, params)
{	
	params = params || {};
	if (!params.user) udb.error('Programming error', 'The user must be specified');
	
	this.init = function()
	{
		buildUI();
		log(params.user);
	}
	
	var self = this;

	var buildUI = function()
	{
		selector
			.addClass('pianos4_main')
			.append($('<div />')
			.append($('<h2 />').text('Welcome to PiAnoS, '+params.user.name)));
			
		udb.app().getModel().rpc('getHomeData', function(data) {
			var mainDiv = selector.find('>div:first');

			mainDiv.append($('<p />')
					.append($('<strong />').text('Your cases')));
					
			if (!data.folder)
			{
				mainDiv.append($('<div />')
					.append($('<p />').text('You need a personal folder to create your own cases (i.e. upload your own images).'))
					.append($('<span />').text('Create one now').button().bind('click', function() {
						udb.app().getModel().rpc('createPersonalFolder', function() {
							window.location.reload();
						});
					}))
				);
			}
			else
			{
				mainDiv.append('<p><a href="#folder/'+data.folder.id+'">Your personal folder</a> contains '+data.folder.exids.length+' exercise'+(data.folder.exids.length==1?'':'s')+'</p>');
			}
			
			var numStarted=0,numDone=0,numTotal=0;
			for (var i in data.progress)
			{
				var ex = data.progress[i];
				numTotal++;
				ex.progress.label2 = 'To do';
				ex.progress.color = 'black';
				if (ex.progress.status >= 4)
				{
					numDone++;
					ex.progress.label2 = 'Done !';
					ex.progress.color = 'green';
				}
				else if (ex.progress.status >= 0)
				{
					numStarted++;
					ex.progress.label2 = 'To continue';
					ex.progress.color = 'blue';
				}
			}
			var percent = 100.0*numDone/numTotal;

			var withOverallProgress = false;
			if (withOverallProgress)
			{
				mainDiv.append($('<p />')
						.append($('<strong />').text('Overall progress : ')).append($('<span />').text(numDone+' / '+numTotal+' trial'+(numDone!=1?'s':'')+' done'+(numStarted?', '+numStarted+' started':''))))
					.append($('<div />').addClass('home_progressbar').progressbar({value:percent}).append($('<span />').addClass('_percent_wrap').append($('<span />').addClass('_percent').text(percent.toFixed(0)+' %'))))
				;
			}
			mainDiv.append($('<p />')
						.append($('<strong />').text('Details')));
			
			var ul = $('<ul />');
			for (var i in data.progress)
			{
				var ex = data.progress[i];
				var li = $('<li />')
					.append($('<span />').addClass('home_details_status')
						.append('[ ')
						.append($('<span />').text(ex.progress.label2).css('color',ex.progress.color))
						.append(' ] '))
					.append($('<a />').attr('href','#exercise/'+ex.id).text(ex.name))
				;
				ul.append(li);
				
			}
			mainDiv.append(ul);
			
			var withPrize = false;
			if (withPrize && numDone == numTotal)
			{
				udb.app().getModel().rpc('getCompletionCode', function(code) {
					var block = $('<div />').addClass('ui-widget');
					
					$('<div />').addClass('ui-widget-header ui-corner-top')
						.css('padding','0.2em 0.5em')
						.text('Congratulations ! ')
						.appendTo(block);
					
					var subject = 'NIJ Study completed';
					var body = 'Hi Glenn,\n\nI\'ve completed the NIJ Study using PiAnoS. Here is my passcode:\n'+code+'\n\nPlease send me my prize!\n';
					
					$('<div />').addClass('ui-widget-content ui-corner-bottom')
						.css('padding','0 1em')
						.append($('<p />').text('You have won a prize ! To obtain it, please send the passcode'))
						.append($('<p />').append($('<span />').addClass('ui-state-default').css('font-weight','bold').css('font-family','courier new').css('padding','0.5em 1.5em').text(code)))
						.append($('<p />').text('to ').append($('<a />').attr('href','mailto:glenn.langenburg@unil.ch?subject='+encodeURIComponent(subject)+'&body='+encodeURIComponent(body)).text('glenn.langenburg@unil.ch')))
						.appendTo(block);
						
					var mainDiv = selector.find('>div:first');
					block.insertAfter(mainDiv.find('h2'));
				});
			}
			
			var lastWeekWarning = false;
			var endOfStudyWarning = false;
			
			if (lastWeekWarning)
			{
				var block = $('<div />').addClass('ui-widget').css('margin-top','1em');
				$('<div />').addClass('ui-widget-header ui-corner-top ui-state-error')
					.css('padding','0.2em 0.5em')
					.text('Last week notice')
					.appendTo(block);
				$('<div />').addClass('ui-widget-content ui-corner-bottom ui-state-highlight')
					.css('padding','0 1em')
					.append($('<p />').text('Dear participant,'))
					.append($('<p />').text('The study will end in at the end of the week, on Sunday, 9th. PiAnoS remains fully functional until that date, and we encourage you to finish the trials - or at least those that you have already started. Do not forget to reclaim your prize if you see the code and email link above !'))
					.append($('<p />').text('We would like to thank you for your participation in this study. We hope you had a great time with PiAnoS !'))
					.append($('<p />').text('Yours sincerly,'))
					.append($('<p />').text('The PiAnoS NIJ project team'))
					.appendTo(block);
				var mainDiv = selector.find('>div:first');
				block.insertAfter(mainDiv.find('h2'));
			}

			if (endOfStudyWarning)
			{
				var block = $('<div />').addClass('ui-widget').css('margin-top','1em');
				$('<div />').addClass('ui-widget-header ui-corner-top ui-state-error')
					.css('padding','0.2em 0.5em')
					.text('Study is over !')
					.appendTo(block);
				$('<div />').addClass('ui-widget-content ui-corner-bottom ui-state-highlight')
					.css('padding','0 1em')
					.append($('<p />').text('Dear participant,'))
					.append($('<p />').text('The study is now (2012-09-10) over. Your results have been collected and archived for analysis by our team. PiAnoS will stay open for little while, so you will still be able to log-in as usual, but further results will not be considered in the research.'))
					.append($('<p />').text('Do not forget to reclaim your prize if you see the code and email link above ! You will be notified by email when your personnal access to PiAnoS is available.'))
					.append($('<p />').text('We would like to thank you again for your participation in this study. Your contribution was very valuable to us. We hope you had a great time with PiAnoS !'))
					.append($('<p />').text('Yours sincerly,'))
					.append($('<p />').text('The PiAnoS NIJ project team'))
					.appendTo(block);
				var mainDiv = selector.find('>div:first');
				block.insertAfter(mainDiv.find('h2'));
			}
		});
	}
}
		
Pianos4Backend.UserExercise = function(selector, params)
{	
	params = params || {};
	if (!params.id) udb.error('Programming error', 'The exercise ID must be specified');
	if (!params.user) udb.error('Programming error', 'The user must be specified');
	
	this.init = function()
	{
		buildUI();
	}
	
	var self = this;

	var buildUI = function()
	{
		udb.app().getModel().rpc('getExercise', {id: params.id, withProgress:true}, function(ex) {
			log(ex);

			var label;
			if (ex.progress.status >= 4)
				label = 'Review your results';
			else if (ex.progress.status >= 0)
				label = 'Resume your work';
			else
				label = 'Start this exercise';
				
			var div = $('<div />')
				.append($('<h2 />').text(ex.name))
				.append($('<p />').addClass('exercise_description').text(ex.description))
				.append($('<span />').addClass('pianos4_image_preview')
					.append($('<img />').attr('src', '?action=get_image&thumb&id='+ex.mark).attr('alt','Mark image')))
				.append($('<span />').addClass('pianos4_image_preview')
					.append($('<img />').attr('src', '?action=get_image&thumb&id='+ex.print).attr('alt','Print image')))
				.append($('<div />').css('margin-top','1em')
					.append($('<a />').attr('href','?action=take&id='+ex.id).text(label).button()))
			;
			
			if (!params.user.tutor && ex.ownerid == params.user.id)
			{
				var canClone = ex.progress.status >= 3;
				div.find('div:last')
					.append($('<a />').css('margin-left','1em').attr('href','#exercise/'+ex.id+'/edit').text('Edit case').button())
					.append($('<a />').css('margin-left','1em').attr('href','#exercise/'+ex.id+'/clone').text('Re-use analysis in a new case').button({'disabled':!canClone}))
				;
			}
		
			selector
				.addClass('pianos4_main')
				.append(div);
		});
	}
}
		
